ConversationContext class final
- Inheritance
-
- Object
- KoahAdContext
- ConversationContext
Constructors
- ConversationContext({required String question, String? answer, String? externalConversationId})
-
const
Properties
- answer → String?
-
final
- externalConversationId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- question → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialize to the JSON shape
/ad_requestsexpects.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override