KoahAdError class final

The request could not complete — a transport failure, a non-2xx response, or a response that failed to decode. Distinct from KoahAdNoFill, which is a successful "no inventory" answer.

Inheritance

Constructors

KoahAdError({required String message, bool fromCache = false})
const

Properties

fromCache → bool
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override